@@ -28,8 +28,8 @@ from urllib.parse import urlparse, quote_plus
 from aiocache import cached
 from httpx import RequestError
 
-from arsenic import get_session, browsers, services
-from arsenic.errors import JavascriptError, UnknownError, ArsenicError
+from wapiti_arsenic import get_session, browsers, services
+from wapiti_arsenic.errors import JavascriptError, UnknownError, ArsenicError
 
 from wapitiCore.attack.cve.checker import (
     CVEChecker, cvss_score_to_wapiti_level, CVE_DIRECTORY, SUPPORTED_SOFTWARES, is_cve_supported_software
@@ -152,8 +152,8 @@ class ModuleWapp(Attack):
     # Store the gitlab private token from env variable
     gitlab_private_token = None
 
-    def __init__(self, crawler, persister, attack_options, stop_event, crawler_configuration):
-        Attack.__init__(self, crawler, persister, attack_options, stop_event, crawler_configuration)
+    def __init__(self, crawler, persister, attack_options, crawler_configuration):
+        Attack.__init__(self, crawler, persister, attack_options, crawler_configuration)
         self.user_config_dir = self.persister.CONFIG_DIR
         if not os.path.isdir(self.user_config_dir):
             os.makedirs(self.user_config_dir)
