@@ -34,9 +34,9 @@ from mitmproxy.master import Master
 from mitmproxy.options import Options
 from mitmproxy.http import Request as MitmRequest
 import httpx
-from arsenic import get_session, browsers, services
-from arsenic.constants import SelectorType
-from arsenic.errors import ArsenicError, ElementNotInteractable, UnknownArsenicError, NoSuchElement
+from wapiti_arsenic import get_session, browsers, services
+from wapiti_arsenic.constants import SelectorType
+from wapiti_arsenic.errors import ArsenicError, ElementNotInteractable, UnknownArsenicError, NoSuchElement
 import structlog
 
 from wapitiCore.net import Request
@@ -68,7 +68,7 @@ def is_interpreted_type(mime_type: str) -> bool:
 
 def set_arsenic_log_level(level: int = WARNING):
     # Create logger
-    logger = getLogger('arsenic')
+    logger = getLogger('wapiti_arsenic')
 
     # We need factory, to return application-wide logger
     def logger_factory():
@@ -104,7 +104,7 @@ def mitm_to_wapiti_request(mitm_request: MitmRequest) -> Optional[Request]:
         # so we will consider values as simple fields but still send using multipart encoding
         post_params.extend(decode_key_value_dict(mitm_request.multipart_form))
 
-    if not enctype and mitm_request.method == "POST":
+    if not enctype and mitm_request.method in ["POST", "PUT", "PATCH"]:
         enctype = mitm_request.headers.get("Content-Type", "")
 
     if enctype == "application/json":
@@ -327,6 +327,7 @@ async def launch_headless_explorer(
             while to_explore and not stop_event.is_set():
                 request = to_explore.popleft()
                 excluded_requests.append(request)
+                request.set_cookies(crawler.cookie_jar)
 
                 if request.method == "GET":
                     try:
